@@ -44,6 +44,7 @@
 
 #include "http.h"
 #include "agent-priv.h"
+#include "socket-priv.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -83,24 +84,18 @@ typedef struct {
 } HttpPriv;
 
 
-struct to_be_sent {
-  guint length;
-  gchar *buf;
-  NiceAddress to;
-};
-
-
 static void socket_close (NiceSocket *sock);
 static gint socket_recv_messages (NiceSocket *sock,
     NiceInputMessage *recv_messages, guint n_recv_messages);
 static gint socket_send_messages (NiceSocket *sock, const NiceAddress *to,
     const NiceOutputMessage *messages, guint n_messages);
+static gint socket_send_messages_reliable (NiceSocket *sock,
+    const NiceAddress *to, const NiceOutputMessage *messages, guint n_messages);
 static gboolean socket_is_reliable (NiceSocket *sock);
-
-static void add_to_be_sent (NiceSocket *sock, const NiceAddress *to,
-    const NiceOutputMessage *messages, guint n_messages);
-static void free_to_be_sent (struct to_be_sent *tbs);
-
+static gboolean socket_can_send (NiceSocket *sock, NiceAddress *addr);
+static void socket_set_writable_callback (NiceSocket *sock,
+    NiceSocketWritableCb callback, gpointer user_data);
+static gboolean socket_is_based_on (NiceSocket *sock, NiceSocket *other);
 
 NiceSocket *
 nice_http_socket_new (NiceSocket *base_socket,
@@ -123,12 +118,16 @@ nice_http_socket_new (NiceSocket *base_socket,
     priv->recv_buf_fill = 0;
     priv->content_length = 0;
 
-
+    sock->type = NICE_SOCKET_TYPE_HTTP;
     sock->fileno = priv->base_socket->fileno;
     sock->addr = priv->base_socket->addr;
     sock->send_messages = socket_send_messages;
+    sock->send_messages_reliable = socket_send_messages_reliable;
     sock->recv_messages = socket_recv_messages;
     sock->is_reliable = socket_is_reliable;
+    sock->can_send = socket_can_send;
+    sock->set_writable_callback = socket_set_writable_callback;
+    sock->is_based_on = socket_is_based_on;
     sock->close = socket_close;
 
     /* Send HTTP CONNECT */
@@ -167,7 +166,8 @@ nice_http_socket_new (NiceSocket *base_socket,
       local_messages.buffers = &local_bufs;
       local_messages.n_buffers = 1;
 
-      nice_socket_send_messages (priv->base_socket, NULL, &local_messages, 1);
+      nice_socket_send_messages_reliable (priv->base_socket, NULL,
+          &local_messages, 1);
       priv->state = HTTP_STATE_INIT;
       g_free (msg);
     }
@@ -194,16 +194,16 @@ socket_close (NiceSocket *sock)
   if (priv->recv_buf)
     g_free (priv->recv_buf);
 
-  g_queue_foreach (&priv->send_queue, (GFunc) free_to_be_sent, NULL);
-  g_queue_clear (&priv->send_queue);
+  nice_socket_free_send_queue (&priv->send_queue);
 
   g_slice_free(HttpPriv, sock->priv);
+  sock->priv = NULL;
 }
 
 static void
 assert_ring_buffer_valid (HttpPriv *priv)
 {
-  g_assert (priv->recv_buf_fill <= priv->recv_buf_length);
+  g_assert_cmpint (priv->recv_buf_fill, <=, priv->recv_buf_length);
   g_assert (priv->recv_buf_pos == 0 ||
       priv->recv_buf_pos < priv->recv_buf_length);
   g_assert (priv->recv_buf_length == 0 || priv->recv_buf != NULL);
@@ -283,6 +283,9 @@ socket_recv_messages (NiceSocket *sock,
   HttpPriv *priv = sock->priv;
   gint ret = -1;
 
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
+
   if (priv->state == HTTP_STATE_CONNECTED) {
     guint i;
 
@@ -538,17 +541,13 @@ retry:
     case HTTP_STATE_CONNECTED:
       {
         gsize len;
-        struct to_be_sent *tbs = NULL;
 
         len = memcpy_ring_buffer_to_input_messages (priv,
             recv_messages, n_recv_messages);
 
         /* Send the pending data */
-        while ((tbs = g_queue_pop_head (&priv->send_queue))) {
-          nice_socket_send (priv->base_socket, &tbs->to, tbs->length, tbs->buf);
-          g_free (tbs->buf);
-          g_slice_free (struct to_be_sent, tbs);
-        }
+        nice_socket_flush_send_queue (priv->base_socket,
+            &priv->send_queue);
 
         return len;
       }
@@ -578,6 +577,9 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
 {
   HttpPriv *priv = sock->priv;
 
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
+
   if (priv->state == HTTP_STATE_CONNECTED) {
     /* Fast path. */
     if (!priv->base_socket)
@@ -588,67 +590,64 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
   } else if (priv->state == HTTP_STATE_ERROR) {
     return -1;
   } else {
-    add_to_be_sent (sock, to, messages, n_messages);
+    return 0;
   }
 
   return n_messages;
 }
 
+static gint
+socket_send_messages_reliable (NiceSocket *sock, const NiceAddress *to,
+    const NiceOutputMessage *messages, guint n_messages)
+{
+  HttpPriv *priv = sock->priv;
+
+  if (priv->state == HTTP_STATE_CONNECTED) {
+    /* Fast path. */
+    if (!priv->base_socket)
+      return -1;
+
+    return nice_socket_send_messages_reliable (priv->base_socket, to, messages,
+        n_messages);
+  } else if (priv->state == HTTP_STATE_ERROR) {
+    return -1;
+  } else {
+    nice_socket_queue_send (&priv->send_queue, to, messages, n_messages);
+  }
+
+  return n_messages;
+}
 
 static gboolean
 socket_is_reliable (NiceSocket *sock)
 {
-  return TRUE;
+  HttpPriv *priv = sock->priv;
+
+  return nice_socket_is_reliable (priv->base_socket);
 }
 
-
-static void
-add_to_be_sent (NiceSocket *sock, const NiceAddress *to,
-    const NiceOutputMessage *messages, guint n_messages)
+static gboolean
+socket_can_send (NiceSocket *sock, NiceAddress *addr)
 {
   HttpPriv *priv = sock->priv;
-  guint i;
 
-  if (n_messages == 0)
-    return;
-
-  /* Compact the message’s buffers before queueing. */
-  for (i = 0; i < n_messages; i++) {
-    const NiceOutputMessage *message = &messages[i];
-    struct to_be_sent *tbs = NULL;
-    guint j;
-    gsize message_len_remaining = output_message_get_size (message);
-    gsize offset = 0;
-
-    if (message_len_remaining == 0)
-      continue;
-
-    tbs = g_slice_new0 (struct to_be_sent);
-    tbs->buf = g_malloc (message_len_remaining);
-    tbs->length = message_len_remaining;
-    if (to)
-      tbs->to = *to;
-    g_queue_push_tail (&priv->send_queue, tbs);
-
-    for (j = 0;
-         (message->n_buffers >= 0 && j < (guint) message->n_buffers) ||
-         (message->n_buffers < 0 && message->buffers[j].buffer != NULL);
-         j++) {
-      const GOutputVector *buffer = &message->buffers[j];
-      gsize len;
-
-      len = MIN (buffer->size, message_len_remaining);
-      memcpy (tbs->buf + offset, buffer->buffer, len);
-      message_len_remaining -= len;
-      offset += len;
-    }
-  }
+  return nice_socket_can_send (priv->base_socket, addr);
 }
 
-
 static void
-free_to_be_sent (struct to_be_sent *tbs)
+socket_set_writable_callback (NiceSocket *sock,
+    NiceSocketWritableCb callback, gpointer user_data)
 {
-  g_free (tbs->buf);
-  g_slice_free (struct to_be_sent, tbs);
+  HttpPriv *priv = sock->priv;
+
+  nice_socket_set_writable_callback (priv->base_socket, callback, user_data);
+}
+
+static gboolean
+socket_is_based_on (NiceSocket *sock, NiceSocket *other)
+{
+  HttpPriv *priv = sock->priv;
+
+  return (sock == other) ||
+      (priv && nice_socket_is_based_on (priv->base_socket, other));
 }
